@@ -73,12 +73,11 @@ DBusPyLibDBusConnection_tp_dealloc(Connection *self)
     }
 
     PyErr_Restore(et, ev, etb);
-    (self->ob_type->tp_free)((PyObject *) self);
+    (Py_TYPE(self)->tp_free)((PyObject *) self);
 }
 
 PyTypeObject DBusPyLibDBusConnection_Type = {
-    PyObject_HEAD_INIT(NULL)
-    0,                      /*ob_size*/
+    PyVarObject_HEAD_INIT(NULL, 0)
     "_dbus_bindings._LibDBusConnection",
     sizeof(DBusPyLibDBusConnection),
     0,                      /*tp_itemsize*/
